NeighborWiringError

Enum NeighborWiringError 

#[non_exhaustive]
pub enum NeighborWiringError { MissingSimplex { simplex_key: SimplexKey, }, InvalidFacetIndex { simplex_key: SimplexKey, facet_index: usize, vertex_count: usize, }, FacetIndexOverflow { facet_index: usize, max: u8, }, WrongSimplexArity { simplex_key: SimplexKey, expected: usize, found: usize, }, ExternalFacetNotFound { simplex_key: SimplexKey, facet_index: u8, facet_hash: u64, }, ExternalFacetAlreadyShared { simplex_key: SimplexKey, facet_index: u8, facet_hash: u64, existing_incidents: usize, }, SelfNeighbor { simplex_key: SimplexKey, }, MissingNeighborTarget { simplex_key: SimplexKey, neighbor_key: SimplexKey, }, AsymmetricNeighbor { simplex_key: SimplexKey, facet_index: usize, neighbor_key: SimplexKey, mirror_facet_index: Option<usize>, neighbor_back: Option<SimplexKey>, }, NeighborWalkExceededSimplexCount { visited: usize, total: usize, }, }
Structured reason why neighbor wiring failed.

Examples

use delaunay::prelude::tds::SimplexKey;
use delaunay::prelude::insertion::NeighborWiringError;
use slotmap::KeyData;

let simplex_key = SimplexKey::from(KeyData::from_ffi(11));
let err = NeighborWiringError::MissingSimplex { simplex_key };
assert!(matches!(err, NeighborWiringError::MissingSimplex { .. }));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingSimplex

A simplex required for neighbor wiring was not found.

Fields

simplex_key: SimplexKey

Missing simplex key.



InvalidFacetIndex

A facet index is outside the referenced simplex’s vertex range.

Fields

simplex_key: SimplexKey

Referenced simplex.

facet_index: usize

Invalid facet index.

vertex_count: usize

Number of vertices in the referenced simplex.



FacetIndexOverflow

A facet index cannot fit in the compact facet-index storage type.

Fields

facet_index: usize

Facet index that overflowed.

max: u8

Maximum storable facet index.



WrongSimplexArity

A simplex has the wrong number of vertices for the triangulation dimension.

Fields

simplex_key: SimplexKey

Simplex with mismatched arity.

expected: usize

Expected number of vertices.

found: usize

Observed number of vertices.



ExternalFacetNotFound

An external facet did not match any new-simplex boundary facet.

Fields

simplex_key: SimplexKey

External simplex being glued.

facet_index: u8

Facet index on the external simplex.

facet_hash: u64

Hash of the external facet vertex set.



ExternalFacetAlreadyShared

An external facet matched a facet already shared by multiple new simplices.

Fields

simplex_key: SimplexKey

External simplex being glued.

facet_index: u8

Facet index on the external simplex.

facet_hash: u64

Hash of the external facet vertex set.

existing_incidents: usize

Number of existing new-simplex incidents for the facet.



SelfNeighbor

A simplex points to itself as a neighbor.

Fields

simplex_key: SimplexKey

Simplex containing the self-neighbor pointer.



MissingNeighborTarget

A neighbor pointer references a missing simplex.

Fields

simplex_key: SimplexKey

Simplex containing the stale neighbor pointer.

neighbor_key: SimplexKey

Missing neighbor key.



AsymmetricNeighbor

A neighbor pointer does not point back through the matching mirror facet.

Fields

simplex_key: SimplexKey

Simplex containing the neighbor pointer.

facet_index: usize

Facet index in simplex_key.

neighbor_key: SimplexKey

Neighbor referenced by simplex_key.

mirror_facet_index: Option<usize>

Matching facet index in neighbor_key, if one could be found.

neighbor_back: Option<SimplexKey>

Neighbor’s pointer back through the mirror facet.



NeighborWalkExceededSimplexCount

Neighbor traversal discovered more simplices than the TDS contains.

Fields

visited: usize

Number of unique simplices visited.

total: usize

Number of simplices in the TDS.